# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.mdb.greenplum.v1 import config_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_config__pb2
from yandex.cloud.mdb.greenplum.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_maintenance__pb2
from yandex.cloud.mdb.greenplum.v1 import pxf_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_pxf__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/mdb/greenplum/v1/cluster.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a*yandex/cloud/mdb/greenplum/v1/config.proto\x1a/yandex/cloud/mdb/greenplum/v1/maintenance.proto\x1a\'yandex/cloud/mdb/greenplum/v1/pxf.proto\x1a\x1dyandex/cloud/validation.proto\"\xfb\x0b\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x04name\x18\x04 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12>\n\x06\x63onfig\x18\x05 \x01(\x0b\x32..yandex.cloud.mdb.greenplum.v1.GreenplumConfig\x12\x1e\n\x0b\x64\x65scription\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x42\n\x06labels\x18\x07 \x03(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.Cluster.LabelsEntry\x12G\n\x0b\x65nvironment\x18\x08 \x01(\x0e\x32\x32.yandex.cloud.mdb.greenplum.v1.Cluster.Environment\x12=\n\nmonitoring\x18\t \x03(\x0b\x32).yandex.cloud.mdb.greenplum.v1.Monitoring\x12L\n\rmaster_config\x18\n \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig\x12N\n\x0esegment_config\x18\x0b \x01(\x0b\x32\x36.yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig\x12\x19\n\x11master_host_count\x18\x0c \x01(\x03\x12\x1a\n\x12segment_host_count\x18\r \x01(\x03\x12\x17\n\x0fsegment_in_host\x18\x0e \x01(\x03\x12\x12\n\nnetwork_id\x18\x0f \x01(\t\x12=\n\x06health\x18\x10 \x01(\x0e\x32-.yandex.cloud.mdb.greenplum.v1.Cluster.Health\x12=\n\x06status\x18\x11 \x01(\x0e\x32-.yandex.cloud.mdb.greenplum.v1.Cluster.Status\x12L\n\x12maintenance_window\x18\x12 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.MaintenanceWindow\x12N\n\x11planned_operation\x18\x13 \x01(\x0b\x32\x33.yandex.cloud.mdb.greenplum.v1.MaintenanceOperation\x12\x1a\n\x12security_group_ids\x18\x14 \x03(\t\x12\x11\n\tuser_name\x18\x15 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x16 \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\x17 \x03(\t\x12G\n\x0e\x63luster_config\x18\x18 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.ClusterConfigSet\x12\x42\n\rcloud_storage\x18\x1a \x01(\x0b\x32+.yandex.cloud.mdb.greenplum.v1.CloudStorage\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"O\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0e\n\nUNBALANCED\x10\x04\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07J\x04\x08\x19\x10\x1a\"\xcf\x06\n\x10\x43lusterConfigSet\x12s\n\x19greenplum_config_set_6_17\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_17H\x00R\x17greenplumConfigSet_6_17\x12s\n\x19greenplum_config_set_6_19\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_19H\x00R\x17greenplumConfigSet_6_19\x12s\n\x19greenplum_config_set_6_21\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_21H\x00R\x17greenplumConfigSet_6_21\x12s\n\x19greenplum_config_set_6_22\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_22H\x00R\x17greenplumConfigSet_6_22\x12j\n\x16greenplum_config_set_6\x18\t \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6H\x00R\x14greenplumConfigSet_6\x12\x46\n\x04pool\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigSet\x12X\n\x15\x62\x61\x63kground_activities\x18\x06 \x01(\x0b\x32\x39.yandex.cloud.mdb.greenplum.v1.BackgroundActivitiesConfig\x12?\n\npxf_config\x18\x08 \x01(\x0b\x32+.yandex.cloud.mdb.greenplum.v1.PXFConfigSetB\x12\n\x10greenplum_configJ\x04\x08\x07\x10\x08\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xb0\x02\n\x0fGreenplumConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12H\n\x19\x62\x61\x63kup_retain_period_days\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-60\x12\x35\n\x06\x61\x63\x63\x65ss\x18\x03 \x01(\x0b\x32%.yandex.cloud.mdb.greenplum.v1.Access\x12\x19\n\x07zone_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x06 \x01(\x08J\x04\x08\x07\x10\t\"C\n\x06\x41\x63\x63\x65ss\x12\x11\n\tdata_lens\x18\x01 \x01(\x08\x12\x0f\n\x07web_sql\x18\x02 \x01(\x08\x12\x15\n\rdata_transfer\x18\x03 \x01(\x08\"\xd6\x01\n\x16GreenplumRestoreConfig\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x01 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12\x35\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0b\x32%.yandex.cloud.mdb.greenplum.v1.Access\x12\x19\n\x07zone_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x05 \x01(\x08\"A\n\x10RestoreResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\"\x1e\n\x0c\x43loudStorage\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x42p\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _CLUSTER_LABELSENTRY._options = None
  _CLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _CLUSTER.fields_by_name['name']._options = None
  _CLUSTER.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _CLUSTER.fields_by_name['description']._options = None
  _CLUSTER.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _GREENPLUMCONFIG.fields_by_name['backup_retain_period_days']._options = None
  _GREENPLUMCONFIG.fields_by_name['backup_retain_period_days']._serialized_options = b'\372\3071\0041-60'
  _GREENPLUMCONFIG.fields_by_name['zone_id']._options = None
  _GREENPLUMCONFIG.fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _GREENPLUMCONFIG.fields_by_name['subnet_id']._options = None
  _GREENPLUMCONFIG.fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _GREENPLUMRESTORECONFIG.fields_by_name['zone_id']._options = None
  _GREENPLUMRESTORECONFIG.fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _GREENPLUMRESTORECONFIG.fields_by_name['subnet_id']._options = None
  _GREENPLUMRESTORECONFIG.fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CLUSTER']._serialized_start=338
  _globals['_CLUSTER']._serialized_end=1869
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=1539
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1584
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1586
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1659
  _globals['_CLUSTER_HEALTH']._serialized_start=1661
  _globals['_CLUSTER_HEALTH']._serialized_end=1740
  _globals['_CLUSTER_STATUS']._serialized_start=1742
  _globals['_CLUSTER_STATUS']._serialized_end=1863
  _globals['_CLUSTERCONFIGSET']._serialized_start=1872
  _globals['_CLUSTERCONFIGSET']._serialized_end=2719
  _globals['_MONITORING']._serialized_start=2721
  _globals['_MONITORING']._serialized_end=2782
  _globals['_GREENPLUMCONFIG']._serialized_start=2785
  _globals['_GREENPLUMCONFIG']._serialized_end=3089
  _globals['_ACCESS']._serialized_start=3091
  _globals['_ACCESS']._serialized_end=3158
  _globals['_GREENPLUMRESTORECONFIG']._serialized_start=3161
  _globals['_GREENPLUMRESTORECONFIG']._serialized_end=3375
  _globals['_RESTORERESOURCES']._serialized_start=3377
  _globals['_RESTORERESOURCES']._serialized_end=3442
  _globals['_CLOUDSTORAGE']._serialized_start=3444
  _globals['_CLOUDSTORAGE']._serialized_end=3474
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.datasphere.v2.jobs import jobs_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_jobs__pb2
from yandex.cloud.datasphere.v2.jobs import project_job_service_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class ProjectJobServiceStub(object):
    """A set of methods for managing Project Jobs. Do not use these methods manually.
    For working with DataSphere Jobs, install DataSphere CLI via `pip install datasphere`.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Create',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CreateProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Clone = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Clone',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CloneProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Execute = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Execute',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ExecuteProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Cancel = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Cancel',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CancelProjectJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReadStdLogs = channel.unary_stream(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/ReadStdLogs',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsResponse.FromString,
                )
        self.ReadLogs = channel.unary_stream(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/ReadLogs',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsResponse.FromString,
                )
        self.DownloadJobFiles = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DownloadJobFiles',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/List',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Get',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.GetProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_jobs__pb2.Job.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Delete',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteData = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DeleteData',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobDataRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteAllData = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DeleteAllData',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteAllProjectJobDataRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.SetDataTtl = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/SetDataTtl',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlResponse.FromString,
                )


class ProjectJobServiceServicer(object):
    """A set of methods for managing Project Jobs. Do not use these methods manually.
    For working with DataSphere Jobs, install DataSphere CLI via `pip install datasphere`.
    """

    def Create(self, request, context):
        """Creates job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Clone(self, request, context):
        """Clone job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Execute(self, request, context):
        """Runs job execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cancel(self, request, context):
        """Cancels running job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadStdLogs(self, request, context):
        """Returns stream of job logs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadLogs(self, request, context):
        """Returns stream of job logs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadJobFiles(self, request, context):
        """Returns download urls for job files.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns job by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes specified job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteData(self, request, context):
        """Delete job data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAllData(self, request, context):
        """Delete all jobs data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDataTtl(self, request, context):
        """Update job data ttl.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectJobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CreateProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Clone': grpc.unary_unary_rpc_method_handler(
                    servicer.Clone,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CloneProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Execute': grpc.unary_unary_rpc_method_handler(
                    servicer.Execute,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ExecuteProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.Cancel,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CancelProjectJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReadStdLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.ReadStdLogs,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsResponse.SerializeToString,
            ),
            'ReadLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.ReadLogs,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsResponse.SerializeToString,
            ),
            'DownloadJobFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadJobFiles,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.GetProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_jobs__pb2.Job.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteData': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteData,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobDataRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteAllData': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAllData,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteAllProjectJobDataRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetDataTtl': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDataTtl,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.datasphere.v2.jobs.ProjectJobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectJobService(object):
    """A set of methods for managing Project Jobs. Do not use these methods manually.
    For working with DataSphere Jobs, install DataSphere CLI via `pip install datasphere`.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Create',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CreateProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Clone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Clone',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CloneProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Execute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Execute',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ExecuteProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Cancel',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CancelProjectJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadStdLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/ReadStdLogs',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/ReadLogs',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadJobFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DownloadJobFiles',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/List',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Get',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.GetProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_jobs__pb2.Job.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Delete',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DeleteData',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobDataRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAllData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DeleteAllData',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteAllProjectJobDataRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDataTtl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/SetDataTtl',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/service_control.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.iam.v1 import resource_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/iam/v1/service_control.proto\x12\x13yandex.cloud.iam.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"yandex/cloud/iam/v1/resource.proto\"\xc0\x02\n\x07Service\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12/\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.Resource\x12.\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x06status\x18\x04 \x01(\x0e\x32#.yandex.cloud.iam.v1.Service.Status\"\x8a\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03\x12\x0c\n\x08\x45NABLING\x10\x04\x12\x0c\n\x08RESUMING\x10\x05\x12\x0b\n\x07PAUSING\x10\x06\x12\r\n\tDISABLING\x10\x07\x12\t\n\x05\x45RROR\x10\x08\x42V\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.service_control_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_SERVICE']._serialized_start=136
  _globals['_SERVICE']._serialized_end=456
  _globals['_SERVICE_STATUS']._serialized_start=318
  _globals['_SERVICE_STATUS']._serialized_end=456
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/redis/v1/resource_preset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/mdb/redis/v1/resource_preset.proto\x12\x19yandex.cloud.mdb.redis.v1\"M\n\x0eResourcePreset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08zone_ids\x18\x02 \x03(\t\x12\x0e\n\x06memory\x18\x03 \x01(\x03\x12\r\n\x05\x63ores\x18\x04 \x01(\x03\x42\x64\n\x1dyandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.redis.v1.resource_preset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redis'
  _globals['_RESOURCEPRESET']._serialized_start=78
  _globals['_RESOURCEPRESET']._serialized_end=155
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iot/devices/v1/registry_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iot.devices.v1 import registry_pb2 as yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/iot/devices/v1/registry_service.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a*yandex/cloud/iot/devices/v1/registry.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"7\n\x12GetRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"r\n\x18GetByNameRegistryRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rregistry_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\"v\n\x15ListRegistriesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x16ListRegistriesResponse\x12\x39\n\nregistries\x18\x01 \x03(\x0b\x32%.yandex.cloud.iot.devices.v1.Registry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x92\x04\n\x15\x43reateRegistryRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x04 \x03(\x0b\x32>.yandex.cloud.iot.devices.v1.CreateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12T\n\x0c\x63\x65rtificates\x18\x05 \x03(\x0b\x32>.yandex.cloud.iot.devices.v1.CreateRegistryRequest.Certificate\x12\x10\n\x08password\x18\x06 \x01(\t\x12<\n\x0blog_options\x18\x07 \x01(\x0b\x32\'.yandex.cloud.iot.devices.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\'\n\x0b\x43\x65rtificate\x12\x18\n\x10\x63\x65rtificate_data\x18\x01 \x01(\t\"-\n\x16\x43reateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\xb0\x03\n\x15UpdateRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12(\n\x04name\x18\x03 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x05 \x03(\x0b\x32>.yandex.cloud.iot.devices.v1.UpdateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12<\n\x0blog_options\x18\x06 \x01(\x0b\x32\'.yandex.cloud.iot.devices.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"D\n\x1fListRegistryCertificatesRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"j\n ListRegistryCertificatesResponse\x12\x46\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.iot.devices.v1.RegistryCertificate\"b\n\x1d\x41\x64\x64RegistryCertificateRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\tJ\x04\x08\x02\x10\x03\"J\n\x1e\x41\x64\x64RegistryCertificateMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\"h\n DeleteRegistryCertificateRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"i\n!DeleteRegistryCertificateMetadata\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"A\n\x1cListRegistryPasswordsRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"a\n\x1dListRegistryPasswordsResponse\x12@\n\tpasswords\x18\x01 \x03(\x0b\x32-.yandex.cloud.iot.devices.v1.RegistryPassword\"[\n\x1a\x41\x64\x64RegistryPasswordRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x08password\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04>=14\"G\n\x1b\x41\x64\x64RegistryPasswordMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\x12\x13\n\x0bpassword_id\x18\x02 \x01(\t\"e\n\x1d\x44\x65leteRegistryPasswordRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"f\n\x1e\x44\x65leteRegistryPasswordMetadata\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x80\x01\n\x1dListDeviceTopicAliasesRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"t\n\x1eListDeviceTopicAliasesResponse\x12\x39\n\x07\x61liases\x18\x01 \x03(\x0b\x32(.yandex.cloud.iot.devices.v1.DeviceAlias\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x94\x01\n\x1dListRegistryOperationsRequest\x12\x19\n\x0bregistry_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"p\n\x1eListRegistryOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x80\x02\n\x1a\x41\x64\x64\x44\x61taStreamExportRequest\x12(\n\x04name\x18\x01 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12!\n\x0bregistry_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12%\n\x11mqtt_topic_filter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x1f\n\x08\x64\x61tabase\x18\x05 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=512\x12\x1d\n\x06stream\x18\x06 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=512\x12(\n\x12service_account_id\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50J\x04\x08\x03\x10\x04\"Q\n\x1b\x41\x64\x64\x44\x61taStreamExportMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\x12\x1d\n\x15\x64\x61ta_stream_export_id\x18\x02 \x01(\t\"o\n\x1d\x44\x65leteDataStreamExportRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x61ta_stream_export_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"`\n\x1e\x44\x65leteDataStreamExportMetadata\x12\x19\n\x0bregistry_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12#\n\x15\x64\x61ta_stream_export_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"A\n\x1cListDataStreamExportsRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"k\n\x1dListDataStreamExportsResponse\x12J\n\x13\x64\x61ta_stream_exports\x18\x01 \x03(\x0b\x32-.yandex.cloud.iot.devices.v1.DataStreamExport2\xfa\x19\n\x0fRegistryService\x12\x8f\x01\n\x03Get\x12/.yandex.cloud.iot.devices.v1.GetRegistryRequest\x1a%.yandex.cloud.iot.devices.v1.Registry\"0\x82\xd3\xe4\x93\x02*\x12(/iot-devices/v1/registries/{registry_id}\x12\x97\x01\n\tGetByName\x12\x35.yandex.cloud.iot.devices.v1.GetByNameRegistryRequest\x1a%.yandex.cloud.iot.devices.v1.Registry\",\x82\xd3\xe4\x93\x02&\x12$/iot-devices/v1/registries:getByName\x12\x93\x01\n\x04List\x12\x32.yandex.cloud.iot.devices.v1.ListRegistriesRequest\x1a\x33.yandex.cloud.iot.devices.v1.ListRegistriesResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/iot-devices/v1/registries\x12\xac\x01\n\x06\x43reate\x12\x32.yandex.cloud.iot.devices.v1.CreateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*\"\n\x16\x43reateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02\x1f\"\x1a/iot-devices/v1/registries:\x01*\x12\xba\x01\n\x06Update\x12\x32.yandex.cloud.iot.devices.v1.UpdateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*\"\n\x16UpdateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02-2(/iot-devices/v1/registries/{registry_id}:\x01*\x12\xc4\x01\n\x06\x44\x65lete\x12\x32.yandex.cloud.iot.devices.v1.DeleteRegistryRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*/\n\x16\x44\x65leteRegistryMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02**(/iot-devices/v1/registries/{registry_id}\x12\xce\x01\n\x10ListCertificates\x12<.yandex.cloud.iot.devices.v1.ListRegistryCertificatesRequest\x1a=.yandex.cloud.iot.devices.v1.ListRegistryCertificatesResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/iot-devices/v1/registries/{registry_id}/certificates\x12\xea\x01\n\x0e\x41\x64\x64\x43\x65rtificate\x12:.yandex.cloud.iot.devices.v1.AddRegistryCertificateRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*5\n\x1e\x41\x64\x64RegistryCertificateMetadata\x12\x13RegistryCertificate\x82\xd3\xe4\x93\x02:\"5/iot-devices/v1/registries/{registry_id}/certificates:\x01*\x12\x81\x02\n\x11\x44\x65leteCertificate\x12=.yandex.cloud.iot.devices.v1.DeleteRegistryCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*:\n!DeleteRegistryCertificateMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x45*C/iot-devices/v1/registries/{registry_id}/certificates/{fingerprint}\x12\xc2\x01\n\rListPasswords\x12\x39.yandex.cloud.iot.devices.v1.ListRegistryPasswordsRequest\x1a:.yandex.cloud.iot.devices.v1.ListRegistryPasswordsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/iot-devices/v1/registries/{registry_id}/passwords\x12\xdb\x01\n\x0b\x41\x64\x64Password\x12\x37.yandex.cloud.iot.devices.v1.AddRegistryPasswordRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*/\n\x1b\x41\x64\x64RegistryPasswordMetadata\x12\x10RegistryPassword\x82\xd3\xe4\x93\x02\x37\"2/iot-devices/v1/registries/{registry_id}/passwords:\x01*\x12\xf5\x01\n\x0e\x44\x65letePassword\x12:.yandex.cloud.iot.devices.v1.DeleteRegistryPasswordRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\xb2\xd2*7\n\x1e\x44\x65leteRegistryPasswordMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42*@/iot-devices/v1/registries/{registry_id}/passwords/{password_id}\x12\xda\x01\n\x16ListDeviceTopicAliases\x12:.yandex.cloud.iot.devices.v1.ListDeviceTopicAliasesRequest\x1a;.yandex.cloud.iot.devices.v1.ListDeviceTopicAliasesResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/iot-devices/v1/registries/{registry_id}:listDeviceTopicAliases\x12\x8e\x01\n\x15ListDataStreamExports\x12\x39.yandex.cloud.iot.devices.v1.ListDataStreamExportsRequest\x1a:.yandex.cloud.iot.devices.v1.ListDataStreamExportsResponse\x12\xa6\x01\n\x13\x41\x64\x64\x44\x61taStreamExport\x12\x37.yandex.cloud.iot.devices.v1.AddDataStreamExportRequest\x1a!.yandex.cloud.operation.Operation\"3\xb2\xd2*/\n\x1b\x41\x64\x64\x44\x61taStreamExportMetadata\x12\x10\x44\x61taStreamExport\x12\xb4\x01\n\x16\x44\x65leteDataStreamExport\x12:.yandex.cloud.iot.devices.v1.DeleteDataStreamExportRequest\x1a!.yandex.cloud.operation.Operation\";\xb2\xd2*7\n\x1e\x44\x65leteDataStreamExportMetadata\x12\x15google.protobuf.Empty\x12\xc6\x01\n\x0eListOperations\x12:.yandex.cloud.iot.devices.v1.ListRegistryOperationsRequest\x1a;.yandex.cloud.iot.devices.v1.ListRegistryOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/iot-devices/v1/registries/{registry_id}/operationsBj\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.devices.v1.registry_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices'
  _GETREGISTRYREQUEST.fields_by_name['registry_id']._options = None
  _GETREGISTRYREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETBYNAMEREGISTRYREQUEST.fields_by_name['folder_id']._options = None
  _GETBYNAMEREGISTRYREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETBYNAMEREGISTRYREQUEST.fields_by_name['registry_name']._options = None
  _GETBYNAMEREGISTRYREQUEST.fields_by_name['registry_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _LISTREGISTRIESREQUEST.fields_by_name['folder_id']._options = None
  _LISTREGISTRIESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTREGISTRIESREQUEST.fields_by_name['page_size']._options = None
  _LISTREGISTRIESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTREGISTRIESREQUEST.fields_by_name['page_token']._options = None
  _LISTREGISTRIESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEREGISTRYREQUEST_LABELSENTRY._options = None
  _CREATEREGISTRYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEREGISTRYREQUEST.fields_by_name['folder_id']._options = None
  _CREATEREGISTRYREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEREGISTRYREQUEST.fields_by_name['name']._options = None
  _CREATEREGISTRYREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _CREATEREGISTRYREQUEST.fields_by_name['description']._options = None
  _CREATEREGISTRYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEREGISTRYREQUEST.fields_by_name['labels']._options = None
  _CREATEREGISTRYREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATEREGISTRYREQUEST_LABELSENTRY._options = None
  _UPDATEREGISTRYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEREGISTRYREQUEST.fields_by_name['registry_id']._options = None
  _UPDATEREGISTRYREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEREGISTRYREQUEST.fields_by_name['name']._options = None
  _UPDATEREGISTRYREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _UPDATEREGISTRYREQUEST.fields_by_name['description']._options = None
  _UPDATEREGISTRYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEREGISTRYREQUEST.fields_by_name['labels']._options = None
  _UPDATEREGISTRYREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _DELETEREGISTRYREQUEST.fields_by_name['registry_id']._options = None
  _DELETEREGISTRYREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTREGISTRYCERTIFICATESREQUEST.fields_by_name['registry_id']._options = None
  _LISTREGISTRYCERTIFICATESREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDREGISTRYCERTIFICATEREQUEST.fields_by_name['registry_id']._options = None
  _ADDREGISTRYCERTIFICATEREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEREGISTRYCERTIFICATEREQUEST.fields_by_name['registry_id']._options = None
  _DELETEREGISTRYCERTIFICATEREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEREGISTRYCERTIFICATEREQUEST.fields_by_name['fingerprint']._options = None
  _DELETEREGISTRYCERTIFICATEREQUEST.fields_by_name['fingerprint']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEREGISTRYCERTIFICATEMETADATA.fields_by_name['registry_id']._options = None
  _DELETEREGISTRYCERTIFICATEMETADATA.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEREGISTRYCERTIFICATEMETADATA.fields_by_name['fingerprint']._options = None
  _DELETEREGISTRYCERTIFICATEMETADATA.fields_by_name['fingerprint']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTREGISTRYPASSWORDSREQUEST.fields_by_name['registry_id']._options = None
  _LISTREGISTRYPASSWORDSREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDREGISTRYPASSWORDREQUEST.fields_by_name['registry_id']._options = None
  _ADDREGISTRYPASSWORDREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDREGISTRYPASSWORDREQUEST.fields_by_name['password']._options = None
  _ADDREGISTRYPASSWORDREQUEST.fields_by_name['password']._serialized_options = b'\212\3101\004>=14'
  _DELETEREGISTRYPASSWORDREQUEST.fields_by_name['registry_id']._options = None
  _DELETEREGISTRYPASSWORDREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEREGISTRYPASSWORDREQUEST.fields_by_name['password_id']._options = None
  _DELETEREGISTRYPASSWORDREQUEST.fields_by_name['password_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEREGISTRYPASSWORDMETADATA.fields_by_name['registry_id']._options = None
  _DELETEREGISTRYPASSWORDMETADATA.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEREGISTRYPASSWORDMETADATA.fields_by_name['password_id']._options = None
  _DELETEREGISTRYPASSWORDMETADATA.fields_by_name['password_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDEVICETOPICALIASESREQUEST.fields_by_name['registry_id']._options = None
  _LISTDEVICETOPICALIASESREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDEVICETOPICALIASESREQUEST.fields_by_name['page_size']._options = None
  _LISTDEVICETOPICALIASESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTDEVICETOPICALIASESREQUEST.fields_by_name['page_token']._options = None
  _LISTDEVICETOPICALIASESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTREGISTRYOPERATIONSREQUEST.fields_by_name['registry_id']._options = None
  _LISTREGISTRYOPERATIONSREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001'
  _LISTREGISTRYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTREGISTRYOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTREGISTRYOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTREGISTRYOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTREGISTRYOPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTREGISTRYOPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['name']._options = None
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['registry_id']._options = None
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['mqtt_topic_filter']._options = None
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['mqtt_topic_filter']._serialized_options = b'\212\3101\006<=1024'
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['database']._options = None
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['database']._serialized_options = b'\350\3071\001\212\3101\005<=512'
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['stream']._options = None
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['stream']._serialized_options = b'\350\3071\001\212\3101\005<=512'
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['service_account_id']._options = None
  _ADDDATASTREAMEXPORTREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEDATASTREAMEXPORTREQUEST.fields_by_name['registry_id']._options = None
  _DELETEDATASTREAMEXPORTREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEDATASTREAMEXPORTREQUEST.fields_by_name['data_stream_export_id']._options = None
  _DELETEDATASTREAMEXPORTREQUEST.fields_by_name['data_stream_export_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEDATASTREAMEXPORTMETADATA.fields_by_name['registry_id']._options = None
  _DELETEDATASTREAMEXPORTMETADATA.fields_by_name['registry_id']._serialized_options = b'\350\3071\001'
  _DELETEDATASTREAMEXPORTMETADATA.fields_by_name['data_stream_export_id']._options = None
  _DELETEDATASTREAMEXPORTMETADATA.fields_by_name['data_stream_export_id']._serialized_options = b'\350\3071\001'
  _LISTDATASTREAMEXPORTSREQUEST.fields_by_name['registry_id']._options = None
  _LISTDATASTREAMEXPORTSREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REGISTRYSERVICE.methods_by_name['Get']._options = None
  _REGISTRYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/iot-devices/v1/registries/{registry_id}'
  _REGISTRYSERVICE.methods_by_name['GetByName']._options = None
  _REGISTRYSERVICE.methods_by_name['GetByName']._serialized_options = b'\202\323\344\223\002&\022$/iot-devices/v1/registries:getByName'
  _REGISTRYSERVICE.methods_by_name['List']._options = None
  _REGISTRYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/iot-devices/v1/registries'
  _REGISTRYSERVICE.methods_by_name['Create']._options = None
  _REGISTRYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateRegistryMetadata\022\010Registry\202\323\344\223\002\037\"\032/iot-devices/v1/registries:\001*'
  _REGISTRYSERVICE.methods_by_name['Update']._options = None
  _REGISTRYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateRegistryMetadata\022\010Registry\202\323\344\223\002-2(/iot-devices/v1/registries/{registry_id}:\001*'
  _REGISTRYSERVICE.methods_by_name['Delete']._options = None
  _REGISTRYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteRegistryMetadata\022\025google.protobuf.Empty\202\323\344\223\002**(/iot-devices/v1/registries/{registry_id}'
  _REGISTRYSERVICE.methods_by_name['ListCertificates']._options = None
  _REGISTRYSERVICE.methods_by_name['ListCertificates']._serialized_options = b'\202\323\344\223\0027\0225/iot-devices/v1/registries/{registry_id}/certificates'
  _REGISTRYSERVICE.methods_by_name['AddCertificate']._options = None
  _REGISTRYSERVICE.methods_by_name['AddCertificate']._serialized_options = b'\262\322*5\n\036AddRegistryCertificateMetadata\022\023RegistryCertificate\202\323\344\223\002:\"5/iot-devices/v1/registries/{registry_id}/certificates:\001*'
  _REGISTRYSERVICE.methods_by_name['DeleteCertificate']._options = None
  _REGISTRYSERVICE.methods_by_name['DeleteCertificate']._serialized_options = b'\262\322*:\n!DeleteRegistryCertificateMetadata\022\025google.protobuf.Empty\202\323\344\223\002E*C/iot-devices/v1/registries/{registry_id}/certificates/{fingerprint}'
  _REGISTRYSERVICE.methods_by_name['ListPasswords']._options = None
  _REGISTRYSERVICE.methods_by_name['ListPasswords']._serialized_options = b'\202\323\344\223\0024\0222/iot-devices/v1/registries/{registry_id}/passwords'
  _REGISTRYSERVICE.methods_by_name['AddPassword']._options = None
  _REGISTRYSERVICE.methods_by_name['AddPassword']._serialized_options = b'\262\322*/\n\033AddRegistryPasswordMetadata\022\020RegistryPassword\202\323\344\223\0027\"2/iot-devices/v1/registries/{registry_id}/passwords:\001*'
  _REGISTRYSERVICE.methods_by_name['DeletePassword']._options = None
  _REGISTRYSERVICE.methods_by_name['DeletePassword']._serialized_options = b'\262\322*7\n\036DeleteRegistryPasswordMetadata\022\025google.protobuf.Empty\202\323\344\223\002B*@/iot-devices/v1/registries/{registry_id}/passwords/{password_id}'
  _REGISTRYSERVICE.methods_by_name['ListDeviceTopicAliases']._options = None
  _REGISTRYSERVICE.methods_by_name['ListDeviceTopicAliases']._serialized_options = b'\202\323\344\223\002A\022?/iot-devices/v1/registries/{registry_id}:listDeviceTopicAliases'
  _REGISTRYSERVICE.methods_by_name['AddDataStreamExport']._options = None
  _REGISTRYSERVICE.methods_by_name['AddDataStreamExport']._serialized_options = b'\262\322*/\n\033AddDataStreamExportMetadata\022\020DataStreamExport'
  _REGISTRYSERVICE.methods_by_name['DeleteDataStreamExport']._options = None
  _REGISTRYSERVICE.methods_by_name['DeleteDataStreamExport']._serialized_options = b'\262\322*7\n\036DeleteDataStreamExportMetadata\022\025google.protobuf.Empty'
  _REGISTRYSERVICE.methods_by_name['ListOperations']._options = None
  _REGISTRYSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0025\0223/iot-devices/v1/registries/{registry_id}/operations'
  _globals['_GETREGISTRYREQUEST']._serialized_start=296
  _globals['_GETREGISTRYREQUEST']._serialized_end=351
  _globals['_GETBYNAMEREGISTRYREQUEST']._serialized_start=353
  _globals['_GETBYNAMEREGISTRYREQUEST']._serialized_end=467
  _globals['_LISTREGISTRIESREQUEST']._serialized_start=469
  _globals['_LISTREGISTRIESREQUEST']._serialized_end=587
  _globals['_LISTREGISTRIESRESPONSE']._serialized_start=589
  _globals['_LISTREGISTRIESRESPONSE']._serialized_end=697
  _globals['_CREATEREGISTRYREQUEST']._serialized_start=700
  _globals['_CREATEREGISTRYREQUEST']._serialized_end=1230
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=1144
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1189
  _globals['_CREATEREGISTRYREQUEST_CERTIFICATE']._serialized_start=1191
  _globals['_CREATEREGISTRYREQUEST_CERTIFICATE']._serialized_end=1230
  _globals['_CREATEREGISTRYMETADATA']._serialized_start=1232
  _globals['_CREATEREGISTRYMETADATA']._serialized_end=1277
  _globals['_UPDATEREGISTRYREQUEST']._serialized_start=1280
  _globals['_UPDATEREGISTRYREQUEST']._serialized_end=1712
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=1144
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1189
  _globals['_UPDATEREGISTRYMETADATA']._serialized_start=1714
  _globals['_UPDATEREGISTRYMETADATA']._serialized_end=1759
  _globals['_DELETEREGISTRYREQUEST']._serialized_start=1761
  _globals['_DELETEREGISTRYREQUEST']._serialized_end=1819
  _globals['_DELETEREGISTRYMETADATA']._serialized_start=1821
  _globals['_DELETEREGISTRYMETADATA']._serialized_end=1866
  _globals['_LISTREGISTRYCERTIFICATESREQUEST']._serialized_start=1868
  _globals['_LISTREGISTRYCERTIFICATESREQUEST']._serialized_end=1936
  _globals['_LISTREGISTRYCERTIFICATESRESPONSE']._serialized_start=1938
  _globals['_LISTREGISTRYCERTIFICATESRESPONSE']._serialized_end=2044
  _globals['_ADDREGISTRYCERTIFICATEREQUEST']._serialized_start=2046
  _globals['_ADDREGISTRYCERTIFICATEREQUEST']._serialized_end=2144
  _globals['_ADDREGISTRYCERTIFICATEMETADATA']._serialized_start=2146
  _globals['_ADDREGISTRYCERTIFICATEMETADATA']._serialized_end=2220
  _globals['_DELETEREGISTRYCERTIFICATEREQUEST']._serialized_start=2222
  _globals['_DELETEREGISTRYCERTIFICATEREQUEST']._serialized_end=2326
  _globals['_DELETEREGISTRYCERTIFICATEMETADATA']._serialized_start=2328
  _globals['_DELETEREGISTRYCERTIFICATEMETADATA']._serialized_end=2433
  _globals['_LISTREGISTRYPASSWORDSREQUEST']._serialized_start=2435
  _globals['_LISTREGISTRYPASSWORDSREQUEST']._serialized_end=2500
  _globals['_LISTREGISTRYPASSWORDSRESPONSE']._serialized_start=2502
  _globals['_LISTREGISTRYPASSWORDSRESPONSE']._serialized_end=2599
  _globals['_ADDREGISTRYPASSWORDREQUEST']._serialized_start=2601
  _globals['_ADDREGISTRYPASSWORDREQUEST']._serialized_end=2692
  _globals['_ADDREGISTRYPASSWORDMETADATA']._serialized_start=2694
  _globals['_ADDREGISTRYPASSWORDMETADATA']._serialized_end=2765
  _globals['_DELETEREGISTRYPASSWORDREQUEST']._serialized_start=2767
  _globals['_DELETEREGISTRYPASSWORDREQUEST']._serialized_end=2868
  _globals['_DELETEREGISTRYPASSWORDMETADATA']._serialized_start=2870
  _globals['_DELETEREGISTRYPASSWORDMETADATA']._serialized_end=2972
  _globals['_LISTDEVICETOPICALIASESREQUEST']._serialized_start=2975
  _globals['_LISTDEVICETOPICALIASESREQUEST']._serialized_end=3103
  _globals['_LISTDEVICETOPICALIASESRESPONSE']._serialized_start=3105
  _globals['_LISTDEVICETOPICALIASESRESPONSE']._serialized_end=3221
  _globals['_LISTREGISTRYOPERATIONSREQUEST']._serialized_start=3224
  _globals['_LISTREGISTRYOPERATIONSREQUEST']._serialized_end=3372
  _globals['_LISTREGISTRYOPERATIONSRESPONSE']._serialized_start=3374
  _globals['_LISTREGISTRYOPERATIONSRESPONSE']._serialized_end=3486
  _globals['_ADDDATASTREAMEXPORTREQUEST']._serialized_start=3489
  _globals['_ADDDATASTREAMEXPORTREQUEST']._serialized_end=3745
  _globals['_ADDDATASTREAMEXPORTMETADATA']._serialized_start=3747
  _globals['_ADDDATASTREAMEXPORTMETADATA']._serialized_end=3828
  _globals['_DELETEDATASTREAMEXPORTREQUEST']._serialized_start=3830
  _globals['_DELETEDATASTREAMEXPORTREQUEST']._serialized_end=3941
  _globals['_DELETEDATASTREAMEXPORTMETADATA']._serialized_start=3943
  _globals['_DELETEDATASTREAMEXPORTMETADATA']._serialized_end=4039
  _globals['_LISTDATASTREAMEXPORTSREQUEST']._serialized_start=4041
  _globals['_LISTDATASTREAMEXPORTSREQUEST']._serialized_end=4106
  _globals['_LISTDATASTREAMEXPORTSRESPONSE']._serialized_start=4108
  _globals['_LISTDATASTREAMEXPORTSRESPONSE']._serialized_end=4215
  _globals['_REGISTRYSERVICE']._serialized_start=4218
  _globals['_REGISTRYSERVICE']._serialized_end=7540
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/repository_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.containerregistry.v1 import repository_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_repository__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/containerregistry/v1/repository_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x32yandex/cloud/containerregistry/v1/repository.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\";\n\x14GetRepositoryRequest\x12#\n\rrepository_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"}\n\x1aGetRepositoryByNameRequest\x12_\n\x0frepository_name\x18\x01 \x01(\tBF\xe8\xc7\x31\x01\xf2\xc7\x31>[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\"\xcc\x01\n\x17ListRepositoriesRequest\x12\x1d\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tfolder_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"x\n\x18ListRepositoriesResponse\x12\x43\n\x0crepositories\x18\x01 \x03(\x0b\x32-.yandex.cloud.containerregistry.v1.Repository\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"o\n\x17UpsertRepositoryRequest\x12T\n\x04name\x18\x01 \x01(\tBF\xe8\xc7\x31\x01\xf2\xc7\x31>[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\"1\n\x18UpsertRepositoryMetadata\x12\x15\n\rrepository_id\x18\x01 \x01(\t\">\n\x17\x44\x65leteRepositoryRequest\x12#\n\rrepository_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"1\n\x18\x44\x65leteRepositoryMetadata\x12\x15\n\rrepository_id\x18\x01 \x01(\t2\x8f\r\n\x11RepositoryService\x12\xaa\x01\n\x03Get\x12\x37.yandex.cloud.containerregistry.v1.GetRepositoryRequest\x1a-.yandex.cloud.containerregistry.v1.Repository\";\x82\xd3\xe4\x93\x02\x35\x12\x33/container-registry/v1/repositories/{repository_id}\x12\xbf\x01\n\tGetByName\x12=.yandex.cloud.containerregistry.v1.GetRepositoryByNameRequest\x1a-.yandex.cloud.containerregistry.v1.Repository\"D\x82\xd3\xe4\x93\x02>\x12</container-registry/v1/repositories/{repository_name}:byName\x12\xac\x01\n\x04List\x12:.yandex.cloud.containerregistry.v1.ListRepositoriesRequest\x1a;.yandex.cloud.containerregistry.v1.ListRepositoriesResponse\"+\x82\xd3\xe4\x93\x02%\x12#/container-registry/v1/repositories\x12\xc3\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/container-registry/v1/repositories/{resource_id}:listAccessBindings\x12\xc1\x01\n\x06Upsert\x12:.yandex.cloud.containerregistry.v1.UpsertRepositoryRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*&\n\x18UpsertRepositoryMetadata\x12\nRepository\x82\xd3\xe4\x93\x02(\"#/container-registry/v1/repositories:\x01*\x12\xd9\x01\n\x06\x44\x65lete\x12:.yandex.cloud.containerregistry.v1.DeleteRepositoryRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*1\n\x18\x44\x65leteRepositoryMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x35*3/container-registry/v1/repositories/{repository_id}\x12\xf3\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02H\"C/container-registry/v1/repositories/{resource_id}:setAccessBindings:\x01*\x12\xff\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x91\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02K\"F/container-registry/v1/repositories/{resource_id}:updateAccessBindings:\x01*B\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.repository_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _GETREPOSITORYREQUEST.fields_by_name['repository_id']._options = None
  _GETREPOSITORYREQUEST.fields_by_name['repository_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETREPOSITORYBYNAMEREQUEST.fields_by_name['repository_name']._options = None
  _GETREPOSITORYBYNAMEREQUEST.fields_by_name['repository_name']._serialized_options = b'\350\3071\001\362\3071>[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*'
  _LISTREPOSITORIESREQUEST.fields_by_name['registry_id']._options = None
  _LISTREPOSITORIESREQUEST.fields_by_name['registry_id']._serialized_options = b'\212\3101\004<=50'
  _LISTREPOSITORIESREQUEST.fields_by_name['folder_id']._options = None
  _LISTREPOSITORIESREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _LISTREPOSITORIESREQUEST.fields_by_name['page_size']._options = None
  _LISTREPOSITORIESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTREPOSITORIESREQUEST.fields_by_name['page_token']._options = None
  _LISTREPOSITORIESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTREPOSITORIESREQUEST.fields_by_name['filter']._options = None
  _LISTREPOSITORIESREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTREPOSITORIESREQUEST.fields_by_name['order_by']._options = None
  _LISTREPOSITORIESREQUEST.fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _UPSERTREPOSITORYREQUEST.fields_by_name['name']._options = None
  _UPSERTREPOSITORYREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071>[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*'
  _DELETEREPOSITORYREQUEST.fields_by_name['repository_id']._options = None
  _DELETEREPOSITORYREQUEST.fields_by_name['repository_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REPOSITORYSERVICE.methods_by_name['Get']._options = None
  _REPOSITORYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0025\0223/container-registry/v1/repositories/{repository_id}'
  _REPOSITORYSERVICE.methods_by_name['GetByName']._options = None
  _REPOSITORYSERVICE.methods_by_name['GetByName']._serialized_options = b'\202\323\344\223\002>\022</container-registry/v1/repositories/{repository_name}:byName'
  _REPOSITORYSERVICE.methods_by_name['List']._options = None
  _REPOSITORYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002%\022#/container-registry/v1/repositories'
  _REPOSITORYSERVICE.methods_by_name['ListAccessBindings']._options = None
  _REPOSITORYSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002F\022D/container-registry/v1/repositories/{resource_id}:listAccessBindings'
  _REPOSITORYSERVICE.methods_by_name['Upsert']._options = None
  _REPOSITORYSERVICE.methods_by_name['Upsert']._serialized_options = b'\262\322*&\n\030UpsertRepositoryMetadata\022\nRepository\202\323\344\223\002(\"#/container-registry/v1/repositories:\001*'
  _REPOSITORYSERVICE.methods_by_name['Delete']._options = None
  _REPOSITORYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteRepositoryMetadata\022\025google.protobuf.Empty\202\323\344\223\0025*3/container-registry/v1/repositories/{repository_id}'
  _REPOSITORYSERVICE.methods_by_name['SetAccessBindings']._options = None
  _REPOSITORYSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002H\"C/container-registry/v1/repositories/{resource_id}:setAccessBindings:\001*'
  _REPOSITORYSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _REPOSITORYSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002K\"F/container-registry/v1/repositories/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETREPOSITORYREQUEST']._serialized_start=318
  _globals['_GETREPOSITORYREQUEST']._serialized_end=377
  _globals['_GETREPOSITORYBYNAMEREQUEST']._serialized_start=379
  _globals['_GETREPOSITORYBYNAMEREQUEST']._serialized_end=504
  _globals['_LISTREPOSITORIESREQUEST']._serialized_start=507
  _globals['_LISTREPOSITORIESREQUEST']._serialized_end=711
  _globals['_LISTREPOSITORIESRESPONSE']._serialized_start=713
  _globals['_LISTREPOSITORIESRESPONSE']._serialized_end=833
  _globals['_UPSERTREPOSITORYREQUEST']._serialized_start=835
  _globals['_UPSERTREPOSITORYREQUEST']._serialized_end=946
  _globals['_UPSERTREPOSITORYMETADATA']._serialized_start=948
  _globals['_UPSERTREPOSITORYMETADATA']._serialized_end=997
  _globals['_DELETEREPOSITORYREQUEST']._serialized_start=999
  _globals['_DELETEREPOSITORYREQUEST']._serialized_end=1061
  _globals['_DELETEREPOSITORYMETADATA']._serialized_start=1063
  _globals['_DELETEREPOSITORYMETADATA']._serialized_end=1112
  _globals['_REPOSITORYSERVICE']._serialized_start=1115
  _globals['_REPOSITORYSERVICE']._serialized_end=2794
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/channel_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import channel_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/video/v1/channel_service.proto\x12\x15yandex.cloud.video.v1\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a#yandex/cloud/video/v1/channel.proto\"\'\n\x11GetChannelRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"}\n\x13ListChannelsRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x64 \x01(\x03\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"g\n\x14ListChannelsResponse\x12\x30\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.video.v1.Channel\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xd3\x01\n\x14\x43reateChannelRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12H\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x37.yandex.cloud.video.v1.CreateChannelRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x04\x10\xc8\x01\"+\n\x15\x43reateChannelMetadata\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"\xfe\x01\n\x14UpdateChannelRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12H\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x37.yandex.cloud.video.v1.UpdateChannelRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x05\x10\xc8\x01\"+\n\x15UpdateChannelMetadata\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"*\n\x14\x44\x65leteChannelRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"+\n\x15\x44\x65leteChannelMetadata\x12\x12\n\nchannel_id\x18\x01 \x01(\t2\xd5\x04\n\x0e\x43hannelService\x12Q\n\x03Get\x12(.yandex.cloud.video.v1.GetChannelRequest\x1a\x1e.yandex.cloud.video.v1.Channel\"\x00\x12\x61\n\x04List\x12*.yandex.cloud.video.v1.ListChannelsRequest\x1a+.yandex.cloud.video.v1.ListChannelsResponse\"\x00\x12~\n\x06\x43reate\x12+.yandex.cloud.video.v1.CreateChannelRequest\x1a!.yandex.cloud.operation.Operation\"$\xb2\xd2* \n\x15\x43reateChannelMetadata\x12\x07\x43hannel\x12~\n\x06Update\x12+.yandex.cloud.video.v1.UpdateChannelRequest\x1a!.yandex.cloud.operation.Operation\"$\xb2\xd2* \n\x15UpdateChannelMetadata\x12\x07\x43hannel\x12\x8c\x01\n\x06\x44\x65lete\x12+.yandex.cloud.video.v1.DeleteChannelRequest\x1a!.yandex.cloud.operation.Operation\"2\xb2\xd2*.\n\x15\x44\x65leteChannelMetadata\x12\x15google.protobuf.EmptyB\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.channel_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _CREATECHANNELREQUEST_LABELSENTRY._options = None
  _CREATECHANNELREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECHANNELREQUEST_LABELSENTRY._options = None
  _UPDATECHANNELREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CHANNELSERVICE.methods_by_name['Create']._options = None
  _CHANNELSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateChannelMetadata\022\007Channel'
  _CHANNELSERVICE.methods_by_name['Update']._options = None
  _CHANNELSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateChannelMetadata\022\007Channel'
  _CHANNELSERVICE.methods_by_name['Delete']._options = None
  _CHANNELSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteChannelMetadata\022\025google.protobuf.Empty'
  _globals['_GETCHANNELREQUEST']._serialized_start=215
  _globals['_GETCHANNELREQUEST']._serialized_end=254
  _globals['_LISTCHANNELSREQUEST']._serialized_start=256
  _globals['_LISTCHANNELSREQUEST']._serialized_end=381
  _globals['_LISTCHANNELSRESPONSE']._serialized_start=383
  _globals['_LISTCHANNELSRESPONSE']._serialized_end=486
  _globals['_CREATECHANNELREQUEST']._serialized_start=489
  _globals['_CREATECHANNELREQUEST']._serialized_end=700
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._serialized_start=648
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._serialized_end=693
  _globals['_CREATECHANNELMETADATA']._serialized_start=702
  _globals['_CREATECHANNELMETADATA']._serialized_end=745
  _globals['_UPDATECHANNELREQUEST']._serialized_start=748
  _globals['_UPDATECHANNELREQUEST']._serialized_end=1002
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._serialized_start=648
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._serialized_end=693
  _globals['_UPDATECHANNELMETADATA']._serialized_start=1004
  _globals['_UPDATECHANNELMETADATA']._serialized_end=1047
  _globals['_DELETECHANNELREQUEST']._serialized_start=1049
  _globals['_DELETECHANNELREQUEST']._serialized_end=1091
  _globals['_DELETECHANNELMETADATA']._serialized_start=1093
  _globals['_DELETECHANNELMETADATA']._serialized_end=1136
  _globals['_CHANNELSERVICE']._serialized_start=1139
  _globals['_CHANNELSERVICE']._serialized_end=1736
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/video_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import video_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_video__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/video/v1/video_service.proto\x12\x15yandex.cloud.video.v1\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a!yandex/cloud/video/v1/video.proto\"#\n\x0fGetVideoRequest\x12\x10\n\x08video_id\x18\x01 \x01(\t\"u\n\x10ListVideoRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x64 \x01(\x03\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"`\n\x11ListVideoResponse\x12,\n\x06videos\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.video.v1.Video\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xe9\x03\n\x12\x43reateVideoRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x04 \x01(\t\x12\x46\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x35.yandex.cloud.video.v1.CreateVideoRequest.LabelsEntry\x12\x37\n\x04tusd\x18\xe8\x07 \x01(\x0b\x32&.yandex.cloud.video.v1.VideoTUSDParamsH\x00\x12H\n\rpublic_access\x18\xd0\x0f \x01(\x0b\x32..yandex.cloud.video.v1.VideoPublicAccessParamsH\x01\x12Q\n\x12\x61uth_system_access\x18\xd2\x0f \x01(\x0b\x32\x32.yandex.cloud.video.v1.VideoAuthSystemAccessParamsH\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06sourceB\x0f\n\raccess_rightsJ\x06\x08\xc9\x01\x10\xe8\x07J\x06\x08\xe9\x07\x10\xd0\x0fJ\x06\x08\xd1\x0f\x10\xd2\x0fJ\x05\x08\x05\x10\xc8\x01\"7\n\x0fVideoTUSDParams\x12\x11\n\tfile_size\x18\x01 \x01(\x03\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\x19\n\x17VideoPublicAccessParams\"\x1d\n\x1bVideoAuthSystemAccessParams\"\'\n\x13\x43reateVideoMetadata\x12\x10\n\x08video_id\x18\x01 \x01(\t\"\xcc\x03\n\x12UpdateVideoRequest\x12\x10\n\x08video_id\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x05 \x01(\t\x12\x46\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x35.yandex.cloud.video.v1.UpdateVideoRequest.LabelsEntry\x12H\n\rpublic_access\x18\xd0\x0f \x01(\x0b\x32..yandex.cloud.video.v1.VideoPublicAccessParamsH\x00\x12Q\n\x12\x61uth_system_access\x18\xd2\x0f \x01(\x0b\x32\x32.yandex.cloud.video.v1.VideoAuthSystemAccessParamsH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\raccess_rightsJ\x06\x08\xc9\x01\x10\xd0\x0fJ\x06\x08\xd1\x0f\x10\xd2\x0fJ\x05\x08\x06\x10\xc8\x01\"\'\n\x13UpdateVideoMetadata\x12\x10\n\x08video_id\x18\x01 \x01(\t\"&\n\x12\x44\x65leteVideoRequest\x12\x10\n\x08video_id\x18\x01 \x01(\t\"\'\n\x13\x44\x65leteVideoMetadata\x12\x10\n\x08video_id\x18\x01 \x01(\t\"\xc0\x01\n\x19PerformVideoActionRequest\x12\x10\n\x08video_id\x18\x01 \x01(\t\x12=\n\x07publish\x18\xe8\x07 \x01(\x0b\x32).yandex.cloud.video.v1.PublishVideoActionH\x00\x12\x41\n\tunpublish\x18\xe9\x07 \x01(\x0b\x32+.yandex.cloud.video.v1.UnpublishVideoActionH\x00\x42\x08\n\x06\x61\x63tionJ\x05\x08\x02\x10\xe8\x07\"\x14\n\x12PublishVideoAction\"\x16\n\x14UnpublishVideoAction\".\n\x1aPerformVideoActionMetadata\x12\x10\n\x08video_id\x18\x01 \x01(\t\"f\n\x18GetVideoPlayerURLRequest\x12\x10\n\x08video_id\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.yandex.cloud.video.v1.VideoPlayerParams\"C\n\x11VideoPlayerParams\x12\x0c\n\x04mute\x18\x01 \x01(\x08\x12\x10\n\x08\x61utoplay\x18\x02 \x01(\x08\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\"=\n\x19GetVideoPlayerURLResponse\x12\x12\n\nplayer_url\x18\x01 \x01(\t\x12\x0c\n\x04html\x18\x02 \x01(\t2\xbe\x06\n\x0cVideoService\x12M\n\x03Get\x12&.yandex.cloud.video.v1.GetVideoRequest\x1a\x1c.yandex.cloud.video.v1.Video\"\x00\x12[\n\x04List\x12\'.yandex.cloud.video.v1.ListVideoRequest\x1a(.yandex.cloud.video.v1.ListVideoResponse\"\x00\x12x\n\x06\x43reate\x12).yandex.cloud.video.v1.CreateVideoRequest\x1a!.yandex.cloud.operation.Operation\" \xb2\xd2*\x1c\n\x13\x43reateVideoMetadata\x12\x05Video\x12x\n\x06Update\x12).yandex.cloud.video.v1.UpdateVideoRequest\x1a!.yandex.cloud.operation.Operation\" \xb2\xd2*\x1c\n\x13UpdateVideoMetadata\x12\x05Video\x12\x88\x01\n\x06\x44\x65lete\x12).yandex.cloud.video.v1.DeleteVideoRequest\x1a!.yandex.cloud.operation.Operation\"0\xb2\xd2*,\n\x13\x44\x65leteVideoMetadata\x12\x15google.protobuf.Empty\x12\x8d\x01\n\rPerformAction\x12\x30.yandex.cloud.video.v1.PerformVideoActionRequest\x1a!.yandex.cloud.operation.Operation\"\'\xb2\xd2*#\n\x1aPerformVideoActionMetadata\x12\x05Video\x12s\n\x0cGetPlayerURL\x12/.yandex.cloud.video.v1.GetVideoPlayerURLRequest\x1a\x30.yandex.cloud.video.v1.GetVideoPlayerURLResponse\"\x00\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.video_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _CREATEVIDEOREQUEST_LABELSENTRY._options = None
  _CREATEVIDEOREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEVIDEOREQUEST_LABELSENTRY._options = None
  _UPDATEVIDEOREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _VIDEOSERVICE.methods_by_name['Create']._options = None
  _VIDEOSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateVideoMetadata\022\005Video'
  _VIDEOSERVICE.methods_by_name['Update']._options = None
  _VIDEOSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateVideoMetadata\022\005Video'
  _VIDEOSERVICE.methods_by_name['Delete']._options = None
  _VIDEOSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteVideoMetadata\022\025google.protobuf.Empty'
  _VIDEOSERVICE.methods_by_name['PerformAction']._options = None
  _VIDEOSERVICE.methods_by_name['PerformAction']._serialized_options = b'\262\322*#\n\032PerformVideoActionMetadata\022\005Video'
  _globals['_GETVIDEOREQUEST']._serialized_start=211
  _globals['_GETVIDEOREQUEST']._serialized_end=246
  _globals['_LISTVIDEOREQUEST']._serialized_start=248
  _globals['_LISTVIDEOREQUEST']._serialized_end=365
  _globals['_LISTVIDEORESPONSE']._serialized_start=367
  _globals['_LISTVIDEORESPONSE']._serialized_end=463
  _globals['_CREATEVIDEOREQUEST']._serialized_start=466
  _globals['_CREATEVIDEOREQUEST']._serialized_end=955
  _globals['_CREATEVIDEOREQUEST_LABELSENTRY']._serialized_start=852
  _globals['_CREATEVIDEOREQUEST_LABELSENTRY']._serialized_end=897
  _globals['_VIDEOTUSDPARAMS']._serialized_start=957
  _globals['_VIDEOTUSDPARAMS']._serialized_end=1012
  _globals['_VIDEOPUBLICACCESSPARAMS']._serialized_start=1014
  _globals['_VIDEOPUBLICACCESSPARAMS']._serialized_end=1039
  _globals['_VIDEOAUTHSYSTEMACCESSPARAMS']._serialized_start=1041
  _globals['_VIDEOAUTHSYSTEMACCESSPARAMS']._serialized_end=1070
  _globals['_CREATEVIDEOMETADATA']._serialized_start=1072
  _globals['_CREATEVIDEOMETADATA']._serialized_end=1111
  _globals['_UPDATEVIDEOREQUEST']._serialized_start=1114
  _globals['_UPDATEVIDEOREQUEST']._serialized_end=1574
  _globals['_UPDATEVIDEOREQUEST_LABELSENTRY']._serialized_start=852
  _globals['_UPDATEVIDEOREQUEST_LABELSENTRY']._serialized_end=897
  _globals['_UPDATEVIDEOMETADATA']._serialized_start=1576
  _globals['_UPDATEVIDEOMETADATA']._serialized_end=1615
  _globals['_DELETEVIDEOREQUEST']._serialized_start=1617
  _globals['_DELETEVIDEOREQUEST']._serialized_end=1655
  _globals['_DELETEVIDEOMETADATA']._serialized_start=1657
  _globals['_DELETEVIDEOMETADATA']._serialized_end=1696
  _globals['_PERFORMVIDEOACTIONREQUEST']._serialized_start=1699
  _globals['_PERFORMVIDEOACTIONREQUEST']._serialized_end=1891
  _globals['_PUBLISHVIDEOACTION']._serialized_start=1893
  _globals['_PUBLISHVIDEOACTION']._serialized_end=1913
  _globals['_UNPUBLISHVIDEOACTION']._serialized_start=1915
  _globals['_UNPUBLISHVIDEOACTION']._serialized_end=1937
  _globals['_PERFORMVIDEOACTIONMETADATA']._serialized_start=1939
  _globals['_PERFORMVIDEOACTIONMETADATA']._serialized_end=1985
  _globals['_GETVIDEOPLAYERURLREQUEST']._serialized_start=1987
  _globals['_GETVIDEOPLAYERURLREQUEST']._serialized_end=2089
  _globals['_VIDEOPLAYERPARAMS']._serialized_start=2091
  _globals['_VIDEOPLAYERPARAMS']._serialized_end=2158
  _globals['_GETVIDEOPLAYERURLRESPONSE']._serialized_start=2160
  _globals['_GETVIDEOPLAYERURLRESPONSE']._serialized_end=2221
  _globals['_VIDEOSERVICE']._serialized_start=2224
  _globals['_VIDEOSERVICE']._serialized_end=3054
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/service_control_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1 import resource_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_resource__pb2
from yandex.cloud.iam.v1 import service_control_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/iam/v1/service_control_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/iam/v1/resource.proto\x1a)yandex/cloud/iam/v1/service_control.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"l\n\x11GetServiceRequest\x12 \n\nservice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc7\x31\x01\"\x8b\x01\n\x13ListServicesRequest\x12\x35\n\x08resource\x18\x01 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"_\n\x14ListServicesResponse\x12.\n\x08services\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.iam.v1.Service\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"o\n\x14\x45nableServiceRequest\x12 \n\nservice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc7\x31\x01\"\\\n\x15\x45nableServiceMetadata\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12/\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.Resource\"o\n\x14ResumeServiceRequest\x12 \n\nservice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc7\x31\x01\"\\\n\x15ResumeServiceMetadata\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12/\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.Resource\"}\n\x13PauseServiceRequest\x12 \n\nservice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc7\x31\x01\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\"[\n\x14PauseServiceMetadata\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12/\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.Resource\"p\n\x15\x44isableServiceRequest\x12 \n\nservice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc7\x31\x01\"]\n\x16\x44isableServiceMetadata\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12/\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.Resource2\xb6\x07\n\x15ServiceControlService\x12r\n\x03Get\x12&.yandex.cloud.iam.v1.GetServiceRequest\x1a\x1c.yandex.cloud.iam.v1.Service\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/iam/v1/services/{service_id}\x12u\n\x04List\x12(.yandex.cloud.iam.v1.ListServicesRequest\x1a).yandex.cloud.iam.v1.ListServicesResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/iam/v1/services\x12\xaa\x01\n\x06\x45nable\x12).yandex.cloud.iam.v1.EnableServiceRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2* \n\x15\x45nableServiceMetadata\x12\x07Service\x82\xd3\xe4\x93\x02(\"#/iam/v1/service/{service_id}:enable:\x01*\x12\xaa\x01\n\x06Resume\x12).yandex.cloud.iam.v1.ResumeServiceRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2* \n\x15ResumeServiceMetadata\x12\x07Service\x82\xd3\xe4\x93\x02(\"#/iam/v1/service/{service_id}:resume:\x01*\x12\xa6\x01\n\x05Pause\x12(.yandex.cloud.iam.v1.PauseServiceRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*\x1f\n\x14PauseServiceMetadata\x12\x07Service\x82\xd3\xe4\x93\x02\'\"\"/iam/v1/service/{service_id}:pause:\x01*\x12\xae\x01\n\x07\x44isable\x12*.yandex.cloud.iam.v1.DisableServiceRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*!\n\x16\x44isableServiceMetadata\x12\x07Service\x82\xd3\xe4\x93\x02)\"$/iam/v1/service/{service_id}:disable:\x01*BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.service_control_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _GETSERVICEREQUEST.fields_by_name['service_id']._options = None
  _GETSERVICEREQUEST.fields_by_name['service_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETSERVICEREQUEST.fields_by_name['resource']._options = None
  _GETSERVICEREQUEST.fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _LISTSERVICESREQUEST.fields_by_name['resource']._options = None
  _LISTSERVICESREQUEST.fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _LISTSERVICESREQUEST.fields_by_name['page_size']._options = None
  _LISTSERVICESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTSERVICESREQUEST.fields_by_name['page_token']._options = None
  _LISTSERVICESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _ENABLESERVICEREQUEST.fields_by_name['service_id']._options = None
  _ENABLESERVICEREQUEST.fields_by_name['service_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ENABLESERVICEREQUEST.fields_by_name['resource']._options = None
  _ENABLESERVICEREQUEST.fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _RESUMESERVICEREQUEST.fields_by_name['service_id']._options = None
  _RESUMESERVICEREQUEST.fields_by_name['service_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESUMESERVICEREQUEST.fields_by_name['resource']._options = None
  _RESUMESERVICEREQUEST.fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _PAUSESERVICEREQUEST.fields_by_name['service_id']._options = None
  _PAUSESERVICEREQUEST.fields_by_name['service_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _PAUSESERVICEREQUEST.fields_by_name['resource']._options = None
  _PAUSESERVICEREQUEST.fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _DISABLESERVICEREQUEST.fields_by_name['service_id']._options = None
  _DISABLESERVICEREQUEST.fields_by_name['service_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DISABLESERVICEREQUEST.fields_by_name['resource']._options = None
  _DISABLESERVICEREQUEST.fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _SERVICECONTROLSERVICE.methods_by_name['Get']._options = None
  _SERVICECONTROLSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\037\022\035/iam/v1/services/{service_id}'
  _SERVICECONTROLSERVICE.methods_by_name['List']._options = None
  _SERVICECONTROLSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\022\022\020/iam/v1/services'
  _SERVICECONTROLSERVICE.methods_by_name['Enable']._options = None
  _SERVICECONTROLSERVICE.methods_by_name['Enable']._serialized_options = b'\262\322* \n\025EnableServiceMetadata\022\007Service\202\323\344\223\002(\"#/iam/v1/service/{service_id}:enable:\001*'
  _SERVICECONTROLSERVICE.methods_by_name['Resume']._options = None
  _SERVICECONTROLSERVICE.methods_by_name['Resume']._serialized_options = b'\262\322* \n\025ResumeServiceMetadata\022\007Service\202\323\344\223\002(\"#/iam/v1/service/{service_id}:resume:\001*'
  _SERVICECONTROLSERVICE.methods_by_name['Pause']._options = None
  _SERVICECONTROLSERVICE.methods_by_name['Pause']._serialized_options = b'\262\322*\037\n\024PauseServiceMetadata\022\007Service\202\323\344\223\002\'\"\"/iam/v1/service/{service_id}:pause:\001*'
  _SERVICECONTROLSERVICE.methods_by_name['Disable']._options = None
  _SERVICECONTROLSERVICE.methods_by_name['Disable']._serialized_options = b'\262\322*!\n\026DisableServiceMetadata\022\007Service\202\323\344\223\002)\"$/iam/v1/service/{service_id}:disable:\001*'
  _globals['_GETSERVICEREQUEST']._serialized_start=288
  _globals['_GETSERVICEREQUEST']._serialized_end=396
  _globals['_LISTSERVICESREQUEST']._serialized_start=399
  _globals['_LISTSERVICESREQUEST']._serialized_end=538
  _globals['_LISTSERVICESRESPONSE']._serialized_start=540
  _globals['_LISTSERVICESRESPONSE']._serialized_end=635
  _globals['_ENABLESERVICEREQUEST']._serialized_start=637
  _globals['_ENABLESERVICEREQUEST']._serialized_end=748
  _globals['_ENABLESERVICEMETADATA']._serialized_start=750
  _globals['_ENABLESERVICEMETADATA']._serialized_end=842
  _globals['_RESUMESERVICEREQUEST']._serialized_start=844
  _globals['_RESUMESERVICEREQUEST']._serialized_end=955
  _globals['_RESUMESERVICEMETADATA']._serialized_start=957
  _globals['_RESUMESERVICEMETADATA']._serialized_end=1049
  _globals['_PAUSESERVICEREQUEST']._serialized_start=1051
  _globals['_PAUSESERVICEREQUEST']._serialized_end=1176
  _globals['_PAUSESERVICEMETADATA']._serialized_start=1178
  _globals['_PAUSESERVICEMETADATA']._serialized_end=1269
  _globals['_DISABLESERVICEREQUEST']._serialized_start=1271
  _globals['_DISABLESERVICEREQUEST']._serialized_end=1383
  _globals['_DISABLESERVICEMETADATA']._serialized_start=1385
  _globals['_DISABLESERVICEMETADATA']._serialized_end=1478
  _globals['_SERVICECONTROLSERVICE']._serialized_start=1481
  _globals['_SERVICECONTROLSERVICE']._serialized_end=2431
# @@protoc_insertion_point(module_scope)
